@@ -6,6 +6,7 @@ class PrincipalFFT:
     """Extract principal FFT components for features generation"""
     def __init__(self, n_components):
         self.n_components = n_components
+        self.original_size = 0
         self.idx = None
 
     def fit(self, X):
@@ -13,6 +14,7 @@ class PrincipalFFT:
         Xfft = rfft(X)
         Xabs = np.abs(Xfft)
         Xmax = Xabs.max(axis=0)
+        self.original_size = len(X[0])
         self.idx = (-Xmax).argsort()[:self.n_components]
         return self
 
